TRouterLoginPlugin class abstract

The user status fetching-tool plugin.

Constructors

TRouterLoginPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
isLogin bool
The login status.
no setter
loginRoutePath String
The route path of Login Page.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didRedirected(String routePath) → dynamic
The Router has been redirected to the route named routePath.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited