TRouterRegister class abstract
Register implements of the every single routes.
Constructors
Properties
- finalModuleName → String
-
The final module name.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- invokes → TRouterInvokeRegister?
-
The method invokes.
no setter
- isRoot → bool
-
The root page that mapped to the path named
/. The moduleName will be ignore if isRoot set totrue. default isfalse.no setter - moduleName → String
-
The name of module.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getName(
String path) → String -
Appending the route name with the given
pathname. -
getPath(
String path) → String -
Appending the final route path with the given
pathname. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
) → List< TRoute> - The page router definition.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited